==> sqlitedbms-0.2.0.tar.gz: sqlitedbms-0.2.0/src/htdocs/client/js/boxRequest.js <==
function boxDbExec(mdi, sql, proc) {
	if (!mdi) return;
	mdi.lastSQL=sql;
	if (mdi.type == 'query') {
		mdi.db.boxTab=mdi.selectedTab;
		mdi.db.boxTabProc=proc;
		mdi.db.setArgv(sql, boxResponse, boxErrResponse);
		mdi.db.exec();
		return mdi.db;
	}else{
		var db=dbGetPool();
		db.box=mdi;
		db.boxTab=mdi.selectedTab;
		db.boxTabProc=proc;
		db.setArgv(sql, boxResponse, boxErrResponse);
		db.exec();
		return db;
	}
}

function boxResponse(dbRes, db) {
	if (!dbRes || !db || !db.box) return;
	var mdi=db.box;
	var tab=db.boxTab;
	var tabProc=db.boxTabProc;

	switch (tab) {
		case 'Fields':
			boxTabField(dbRes, mdi, tab, tabProc);
		break;
		case 'Index':
			//boxTabIndexDesc(dbRes, mdi, tab, tabProc);
		break;
		case 'Data':
			switch (tabProc) {
				case 'delete':
					if (mdi.grid && mdi.grid.dataset)
						mdi.grid.dataset.dbExec();
				break;
				case 'update':
				break;
				default:
					if (mdi.grid)
						mdi.grid.dataset.dbResponse(dbRes);
				break;
			}
		break;
		case 'Explain':
			boxTabExplain(dbRes, mdi, tabProc);
		break;
		case 'SQL':
		case 'Result':
			if (dbRes.changes[0] > 0)
				alert(dbRes.changes[0]+' rows changed.');
			else if (dbRes.row)
				boxTabResult(dbRes, mdi, tabProc);
			else
				alert('Execute success. But no return data.');
		break;
	}
}

function boxErrResponse(dbRes, db) {
	if (!dbRes || !db || !db.box) return;
	var mdi=db.box;
	var tab=db.boxTab;
	var tabProc=db.boxTabProc;
	switch (tab) {
		case 'Data':
			if (mdi.grid && mdi.grid.dataset && tabProc)
				mdi.grid.dataset.dbExec();
			else
				alert('Error: '+dbRes.message[0]);
		break;
		default:
			alert('Error: '+dbRes.message[0]);
		break;
	}
}

==> sqlitedbms-0.3.0.tar.gz: sqlitedbms-0.3.0/src/htdocs/client/js/boxRequest.js <==
function boxDbExec(mdi, sql, proc) {
	if (!mdi) return;
	mdi.lastSQL=sql;
	if (mdi.type == 'query') {
		mdi.db.boxTab=mdi.selectedTab;
		mdi.db.boxTabProc=proc;
		mdi.db.setArgv(sql, boxResponse, boxErrResponse);
		mdi.db.exec();
		return mdi.db;
	}else{
		var db=dbGetPool();
		db.box=mdi;
		db.boxTab=mdi.selectedTab;
		db.boxTabProc=proc;
		db.setArgv(sql, boxResponse, boxErrResponse);
		db.exec();
		return db;
	}
}

function boxResponse(dbRes, db) {
	if (!dbRes || !db || !db.box) return;
	var mdi=db.box;
	var tab=db.boxTab;
	var tabProc=db.boxTabProc;

	switch (tab) {
		case 'Fields':
			boxTabField(dbRes, mdi, tab, tabProc);
		break;
		case 'Index':
			//boxTabIndexDesc(dbRes, mdi, tab, tabProc);
		break;
		case 'Data':
			switch (tabProc) {
				case 'insert':
				case 'update':
				case 'delete':
					if (mdi.grid && mdi.grid.dataset)
						mdi.grid.dataset.dbExec();
				break;
				default:
					if (mdi.grid)
						mdi.grid.dataset.dbResponse(dbRes);
				break;
			}
		break;
		case 'Explain':
			boxTabExplain(dbRes, mdi, tabProc);
		break;
		case 'SQL':
		case 'Result':
			if (dbRes.row || dbRes.columns)
				boxTabResult(dbRes, mdi, tabProc);
			else if (dbRes.changes[0] > 0)
				alert(dbRes.changes[0]+' rows changed.');
			else
				alert('Execute success. But no return data.');
		break;
	}
}

function boxErrResponse(dbRes, db) {
	if (!dbRes || !db || !db.box) return;
	var mdi=db.box;
	var tab=db.boxTab;
	var tabProc=db.boxTabProc;
	switch (tab) {
		case 'Data':
			if (mdi.grid && mdi.grid.dataset && tabProc)
				mdi.grid.dataset.dbExec();
			else
				alert('Error: '+dbRes.message[0]);
		break;
		default:
			alert('Error: '+dbRes.message[0]);
		break;
	}
}
